@@ -6,7 +6,6 @@ use 5.008001;
 use strict;
 use warnings;
 use Carp;
-use File::Temp;
 use LWP::UserAgent ();
 use Apache::Sling::AuthnUtil;
 use Apache::Sling::Print;
@@ -19,7 +18,7 @@ use base qw(Exporter);
 
 our @EXPORT_OK = ();
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 #{{{sub new
 sub new {
@@ -28,19 +27,12 @@ sub new {
     my $verbose =
       ( defined ${$sling}->{'Verbose'} ? ${$sling}->{'Verbose'} : 0 );
 
-    my $lwp_user_agent = LWP::UserAgent->new( keep_alive => 1 );
-    push @{ $lwp_user_agent->requests_redirectable }, 'POST';
-    my $tmp_cookie_file_name =
-      File::Temp::tempnam( File::Temp::tempdir( CLEANUP => 1 ), 'authn' );
-    $lwp_user_agent->cookie_jar( { file => $tmp_cookie_file_name } );
-    if ( defined ${$sling}->{'Referer'} ) {
-        $lwp_user_agent->default_header( 'Referer' => ${$sling}->{'Referer'} );
-    }
+    my $lwp_user_agent = $class->user_agent($sling);
 
     my $response;
     my $authn = {
         BaseURL  => "$url",
-        LWP      => \$lwp_user_agent,
+        LWP      => $lwp_user_agent,
         Type     => ${$sling}->{'Auth'},
         Username => ${$sling}->{'User'},
         Password => ${$sling}->{'Pass'},
@@ -50,8 +42,12 @@ sub new {
         Log      => ${$sling}->{'Log'}
     };
 
-# Authn references itself to be compatibile with Apache::Sling::Request::request
+ # Authn references itself to be compatible with Apache::Sling::Request::request
     $authn->{'Authn'} = \$authn;
+
+  # Add a reference to the authn object to the sling object to make it easier to
+  # pass a subclassed authn object through:
+    ${$sling}->{'Authn'} = \$authn;
     bless $authn, $class;
     return $authn;
 }
@@ -86,7 +82,8 @@ sub basic_login {
 #{{{sub login_user
 sub login_user {
     my ($authn) = @_;
-    $authn->{'Type'} = ( defined $authn->{'Type'} ? $authn->{'Type'} : 'basic' );
+    $authn->{'Type'} =
+      ( defined $authn->{'Type'} ? $authn->{'Type'} : 'basic' );
 
     # Apply basic authentication to the user agent if url, username and
     # password are supplied:
@@ -179,6 +176,21 @@ sub switch_user {
 
 #}}}
 
+#{{{sub user_agent
+sub user_agent {
+    my ( $class, $sling ) = @_;
+    my $lwp_user_agent = LWP::UserAgent->new( keep_alive => 1 );
+    push @{ $lwp_user_agent->requests_redirectable }, 'POST';
+    my $tmp_cookie_file_name;
+    $lwp_user_agent->cookie_jar( { file => \$tmp_cookie_file_name } );
+    if ( defined ${$sling}->{'Referer'} ) {
+        $lwp_user_agent->default_header( 'Referer' => ${$sling}->{'Referer'} );
+    }
+    return \$lwp_user_agent;
+}
+
+#}}}
+
 1;
 
 __END__
